@@ -16,7 +16,7 @@ Usage::
     session_client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
     ```
 """
-from mypy_boto3_workmailmessageflow.client import WorkMailMessageFlowClient
+from .client import WorkMailMessageFlowClient
 
 Client = WorkMailMessageFlowClient
 
